@@ -29,6 +29,7 @@ from itertools import *
 import operator
 
 from calculate.lib.cl_lang import setLocalTranslate, _
+from calculate.lib.variables.system import RootType
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
 
@@ -160,7 +161,9 @@ class AutoPartition(object):
         fdisk.write(WRITE_AND_QUIT)
 
         fdisk.success()
-        self._waitDevice(device[0] + str(num - 1))
+        # ожидаение появления устройств ({device}{partnum} или {device}p{partnum})
+        self._waitDevice("%s%s"%(device[0],str(num - 1)),
+                         "%sp%s"%(device[0],str(num - 1)))
 
     def recreatePartitionTableGpt(self, device, data, bios_grub=True,
                                   bios_grub_size=0):
@@ -202,11 +205,16 @@ class AutoPartition(object):
             fdisk.write(NEW_BIOSBOOT_PARTITION % "")
         fdisk.write(WRITE_AND_QUIT)
         fdisk.success()
-        self._waitDevice(device[0] + str(num - 1))
+        # ожидаение появления устройств ({device}{partnum} или {device}p{partnum})
+        self._waitDevice("%s%s"%(device[0],str(num - 1)),
+                         "%sp%s"%(device[0],str(num - 1)))
 
-    def _waitDevice(self, device):
+    def _waitDevice(self, *devices):
+        """
+        Ожидание одного из указанных устройств
+        """
         for waittime in (0.1, 0.2, 0.5, 1, 2, 4):
-            if path.exists(device):
+            if any(path.exists(x) for x in devices):
                 return True
             else:
                 sleep(waittime)
@@ -529,7 +537,6 @@ class VariableClAutopartitionSet(Variable):
     Using autopartition
     """
     type = "bool"
-    value = "off"
     element = "radio"
     opt = ["--autopartition", "-p"]
 
@@ -538,8 +545,16 @@ class VariableClAutopartitionSet(Variable):
         self.help = _("autopartition")
 
     def choice(self):
-        return [("off", _("Use the current partitions")),
-                ("on", _("Autopartition"))]
+        return [("on", _("Autopartition")),
+                ("off", _("Use the current partitions"))]
+
+    def get(self):
+        if self.Get('os_root_type_ext') in (RootType.LiveCD, RootType.LiveFlash,
+                                            RootType.IsoScanFlash,
+                                            RootType.NetBoot):
+            return "on"
+        else:
+            return "off"
 
 
 class VariableClAutopartitionBriefSet(VariableClAutopartitionSet):
@@ -750,6 +765,11 @@ class VariableClAutopartitionDiskDev(AutopartitionHelper, ReadonlyVariable):
         Generate disks for automount scheme
         """
         number = 1
+        if self.Select('install.os_device_array_set',
+            where='install.os_device_dev', eq=devices[0],limit=1) == 'on':
+            pattern = "%sp%d"
+        else:
+            pattern = "%s%d"
         for line in self.deviceOpts(scheme):
             # for dos 4 - extension
             # for gpt 4 - for bios_boot
@@ -757,7 +777,7 @@ class VariableClAutopartitionDiskDev(AutopartitionHelper, ReadonlyVariable):
                 and (self.Get(
                     'cl_autopartition_bios_grub_set') == 'on' or dos)):
                 number += 1
-            yield "%s%d" % (devices[0], number)
+            yield pattern % (devices[0], number)
             number += 1
 
     def generateLvm(self, scheme=(), devices=(), **kwargs):
