@@ -1879,8 +1879,7 @@ class VariableOsInstallMbr(LocationHelper, Variable):
         """Get default Master boot record install"""
         if self.Get('os_install_uefi_set') == 'on':
             return []
-        if self.Get('cl_autopartition_set') == 'on' and \
-                        self.Get('cl_autopartition_lvm_set') == 'on':
+        if self.Get('cl_autopartition_set') == 'on':
             return self.Get('cl_autopartition_device')
         if self.Get('os_install_root_type') in ("flash", "usb-hdd"):
             rootdev = self.Get('os_install_root_dev')
